@@ -1,12 +1,14 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
+
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import { initializeControls, getSourcePath, getResourceID } from 'temptifly'
@@ -40,6 +42,7 @@ export const discoverGroupsFromSource = (
       const newGroup = initializeControls(
         groupData,
         editor,
+        null,
         i18n,
         active.length + 1,
         true
@@ -144,7 +147,7 @@ const discoverChannelFromSource = (
     groupControlData.forEach(cd => {
       cd.groupControlData = groupControlData
     })
-    initializeControls(groupControlData, editor, i18n)
+    initializeControls(groupControlData, editor, null, i18n)
 
     // initialize channel namespace
     const path = 'Subscription[0].spec.channel'
