@@ -290,9 +290,9 @@ export const calculateArgoClusterStatus = clusterData => {
   const clusterJoined = clusterData.ManagedClusterJoined
   const clusterAvailable = clusterData.ManagedClusterConditionAvailable
 
-  if (clusterAccepted == false) {
+  if (clusterAccepted === false) {
     status = 'notaccepted'
-  } else if (clusterJoined == false) {
+  } else if (clusterJoined === false) {
     status = 'pendingimport'
   } else {
     status = clusterAvailable && clusterAvailable === 'True' ? 'ok' : 'offline'
@@ -371,6 +371,9 @@ const getPulseStatusForGenericNode = node => {
   const onlineClusters = getOnlineClusters(node)
   if (!resourceMap || onlineClusters.length === 0) {
     pulse = 'orange' //resource not available
+    if (nodeType === 'placement') {
+      pulse = 'green'
+    }
     return pulse
   }
   if (!allClustersAreOnline(clusterNames, onlineClusters)) {
@@ -854,6 +857,17 @@ export const createResourceSearchLink = node => {
   //returns search link for resource
   if (nodeType === 'cluster') {
     if (isSearchAvailable()) {
+      let clusterNames = _.get(node, 'specs.clustersNames') || []
+      if (clusterNames.length === 0) {
+        clusterNames = _.get(node, 'specs.appClusters') || []
+      }
+      if (clusterNames.length === 0) {
+        const nodeClusters = _.get(node, 'specs.clusters')
+        nodeClusters.forEach(cls => {
+          clusterNames.push(cls.name)
+        })
+      }
+      const clusterNameStr = clusterNames ? clusterNames.join() : undefined
       result = {
         type: 'link',
         value: {
@@ -861,7 +875,10 @@ export const createResourceSearchLink = node => {
           id: node.id,
           data: {
             action: 'show_search',
-            name: (node.name && R.replace(/ /g, '')(node.name)) || 'undefined', // take out spaces
+            name:
+              (node.name && R.replace(/ /g, '')(node.name)) ||
+              clusterNameStr ||
+              'undefined', // take out spaces
             kind: 'cluster'
           },
           indent: true
@@ -925,10 +942,10 @@ export const removeReleaseGeneratedSuffix = name => {
 export const getNameWithoutChartRelease = (
   relatedKind,
   name,
-  isHelmRelease
+  hasHelmReleases
 ) => {
   const kind = _.get(relatedKind, 'kind', '')
-  if (kind === 'subscription' || !isHelmRelease.value) {
+  if (kind === 'subscription' || !hasHelmReleases.value) {
     return name //ignore subscription objects or objects where the name is not created from the _hostingDeployable
   }
 
@@ -1108,7 +1125,7 @@ export const setupResourceModel = (
   list,
   resourceMap,
   isClusterGrouped,
-  isHelmRelease,
+  hasHelmReleases,
   topology,
   lastUpdated
 ) => {
@@ -1218,7 +1235,7 @@ export const setupResourceModel = (
       const nameWithoutChartRelease = getNameWithoutChartRelease(
         relatedKind,
         nameNoHashIngressPod,
-        isHelmRelease
+        hasHelmReleases
       )
 
       let name = computeResourceName(
@@ -1331,6 +1348,7 @@ export const setResourceDeployStatus = (node, details, activeFilters) => {
       R.contains(node.type, [
         'application',
         'placements',
+        'placement',
         'cluster',
         'subscription'
       ]))
