@@ -1,15 +1,20 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
-import { StatusIcon, ClusterCountIcon } from '../constants.js'
+import {
+  StatusIcon,
+  ClusterCountIcon,
+  ArgoAppCountIcon
+} from '../constants.js'
 import msgs from '../../../../../nls/platform.properties'
 import _ from 'lodash'
 
@@ -151,15 +156,24 @@ const getStd = array => {
 export const updateNodeIcons = nodes => {
   nodes.forEach(node => {
     const nodeIcons = {}
-    const { type, layout = {} } = node
+    const { type, layout = {}, specs = {} } = node
 
     // status icon
     let nodeStatus = ''
     let disabled = false
 
+    if (
+      specs.raw &&
+      type === 'application' &&
+      specs.isDesign &&
+      specs.raw.apiVersion.indexOf('argoproj.io') > -1
+    ) {
+      layout.argoAppCountIcon = ArgoAppCountIcon
+      layout.argoAppCount = _.get(specs, 'relatedApps', [{}]).length
+    }
+
     if (type === 'cluster') {
       // determine icon
-      const { specs = {} } = node
       if (specs.clusterStatus) {
         const {
           hasWarning,
@@ -179,8 +193,12 @@ export const updateNodeIcons = nodes => {
         nodeStatus = status
         disabled = isDisabled
       }
+      const clustersCount =
+        _.get(specs, 'clusters', []).length ||
+        _.get(specs, 'appClusters', []).length ||
+        _.get(specs, 'clustersNames', []).length
       layout.clusterCountIcon = ClusterCountIcon
-      layout.clusterCount = specs.clusters.length
+      layout.clusterCount = clustersCount
     }
 
     const pulse = _.get(node, 'specs.pulse', '')
