@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import * as d3 from 'd3'
@@ -15,6 +16,7 @@ import { counterZoom, getTooltip } from '../../utils/diagram-helpers'
 import '../../../../../graphics/diagramShapes.svg'
 import '../../../../../graphics/diagramIcons.svg'
 import _ from 'lodash'
+import { kubeNaming, titleBeautify } from '../defaults/titles'
 
 import {
   FilterResults,
@@ -31,6 +33,9 @@ const gClusterCountText = 'g.clusterCountText'
 const useNodeIcon = 'use.nodeIcon'
 const useClusterCountIcon = 'use.clusterCountIcon'
 const dotClusterCountIcon = '.clusterCountIcon'
+const gArgoAppCountText = 'g.argoAppCountText'
+const useArgoAppCountIcon = 'use.argoAppCountIcon'
+const dotArgoAppCountIcon = '.argoAppCountIcon'
 
 // fix d3-selection-multi not added to d3
 import 'd3-selection-multi'
@@ -197,7 +202,10 @@ export default class NodeHelper {
     this.updateNodeIcons()
 
     // cluster count text
-    this.createClusterCountText(draw, newNodes)
+    this.createClusterCountText(draw, nodes)
+
+    // argo app count text
+    this.createArgoAppCountText(draw, nodes)
   };
 
   createNodePulse = nodes => {
@@ -329,15 +337,17 @@ export default class NodeHelper {
         // normal label
         nodeLabelGroup
           .text(add => {
-            layout.label.split('\n').forEach(line => {
-              if (line) {
-                add
-                  .tspan(line)
-                  .addClass('counter-zoom beg')
-                  .font({ 'font-weight': 'bold' })
-                  .newLine()
-              }
-            })
+            if (layout.type) {
+              titleBeautify(layout.label.indexOf('\n'), kubeNaming(layout.type))
+                .split('\n')
+                .forEach(line => {
+                  add
+                    .tspan(line)
+                    .addClass('counter-zoom beg')
+                    .font({ 'font-weight': 'bold' })
+                    .newLine()
+                })
+            }
             if (layout.description) {
               layout.description.split('\n').forEach(line => {
                 if (line) {
@@ -383,6 +393,9 @@ export default class NodeHelper {
       return layout.type === 'cluster'
     })
 
+    const clusterCountTextNodes = clusterNode.selectAll(gClusterCountText)
+    clusterCountTextNodes.remove()
+
     clusterNode
       .append('g')
       .attr('class', 'clusterCountText')
@@ -402,6 +415,37 @@ export default class NodeHelper {
       .call(fixedD3.drag().on('drag', this.dragNode))
   };
 
+  // Only for argo app nodes, put the app count text
+  createArgoAppCountText = (draw, nodes) => {
+    const argoAppNode = nodes.filter(d => {
+      const { layout } = d
+      return layout.type === 'application'
+    })
+
+    const argoAppCountTextNodes = argoAppNode.selectAll(gArgoAppCountText)
+    argoAppCountTextNodes.remove()
+
+    argoAppNode
+      .append('g')
+      .attr('class', 'argoAppCountText')
+      .html(({ layout }) => {
+        const argoAppTextGroup = draw.group()
+        // Generate text SVG on the fly
+        argoAppTextGroup.text(add => {
+          if (layout.argoAppCount) {
+            add
+              .tspan(layout.argoAppCount)
+              .addClass('count')
+              .font({ fill: 'white', 'font-weight': 'bold' })
+              .newLine()
+          }
+        })
+
+        return argoAppTextGroup.svg()
+      })
+      .call(fixedD3.drag().on('drag', this.dragNode))
+  };
+
   layoutBackgroundRect = selectionB => {
     selectionB.each(({ layout }, i, ns) => {
       layout.textBBox = ns[i].getBBox()
@@ -449,7 +493,7 @@ export default class NodeHelper {
         }
       })
 
-    //special icon for the cluster node count
+    // special icon for the cluster node count
     const clusterNode = this.svg
       .select('g.nodes')
       .selectAll('g.node')
@@ -476,6 +520,33 @@ export default class NodeHelper {
         }
       })
 
+    // special icon for the cluster node count
+    const appNode = this.svg
+      .select('g.nodes')
+      .selectAll('g.node')
+      .filter(d => {
+        const { layout } = d
+        return layout.type === 'application'
+      })
+    const appSVGIcon = appNode
+      .selectAll(useArgoAppCountIcon)
+      .data(({ layout: { argoAppCountIcon } }) => {
+        return argoAppCountIcon ? [argoAppCountIcon] : []
+      })
+    appSVGIcon
+      .enter()
+      .append('use')
+      .attrs(({ icon, classType, width, height }) => {
+        return {
+          'xlink:href': `#diagramIcons_${icon}`,
+          width: `${width}px`,
+          height: `${height}px`,
+          'pointer-events': 'none',
+          tabindex: -1,
+          class: `argoAppCountIcon ${classType}`
+        }
+      })
+
     // png icons
     nodes.selectAll('image.nodeIcon').remove()
     const pngIcons = nodes
@@ -652,6 +723,9 @@ export default class NodeHelper {
     // move cluster count icon
     this.moveIcons(nodeLayer, dotClusterCountIcon)
 
+    // move argo app count icon
+    this.moveIcons(nodeLayer, dotArgoAppCountIcon)
+
     if (this.showsShapeTitles) {
       moveTitles(this.svg)
     }
@@ -659,6 +733,8 @@ export default class NodeHelper {
     moveLabels(this.svg)
     // move clusterCountText
     moveClusterCountText(this.svg)
+    // move argoAppCountText
+    moveArgoAppCountText(this.svg)
   };
 
   moveIcons = (nodeLayer, iconClass) => {
@@ -726,6 +802,9 @@ export default class NodeHelper {
       // drag cluster count icon
       this.dragIcons(node, dotClusterCountIcon)
 
+      // drag argo app count icon
+      this.dragIcons(node, dotArgoAppCountIcon)
+
       // drag status message
       node.selectAll(textNodeStatus).attrs(({ textBBox: { dy } }, i, ns) => {
         const { layout: { x, y } } = d3.select(ns[i].parentNode).datum()
@@ -789,6 +868,38 @@ export default class NodeHelper {
           })
       })
 
+      //drag argo app count text
+      const argoAppCountText = node.selectAll(gArgoAppCountText)
+      argoAppCountText.each((d, i, ns) => {
+        d3
+          .select(ns[i])
+          .selectAll('text')
+          .attr('x', () => {
+            return layout.x + NODE_RADIUS - 2
+          })
+          .attr('y', () => {
+            return layout.y + 4 * (layout.scale || 1)
+          })
+        d3
+          .select(ns[i])
+          .selectAll('rect')
+          .attr('x', () => {
+            return layout.x - layout.textBBox.width / 2
+          })
+          .attr('y', () => {
+            return layout.y + NODE_RADIUS * (layout.scale || 1) + 2
+          })
+        d3
+          .select(ns[i])
+          .selectAll('tspan')
+          .attr('x', () => {
+            return layout.x + NODE_RADIUS - 2
+          })
+          .attr('y', () => {
+            return layout.y + 4 * (layout.scale || 1)
+          })
+      })
+
       // drag node label
       const nodeLabels = node.selectAll(gNodeLabel)
       nodeLabels.each((d, i, ns) => {
@@ -966,6 +1077,9 @@ export const counterZoomLabels = (svg, currentZoom) => {
     // cluster count icon
     setIconVisibility(nodeLayer, useClusterCountIcon)
 
+    // argo app count icon
+    setIconVisibility(nodeLayer, useArgoAppCountIcon)
+
     ///////// STATUS //////////////////
     nodeLayer
       .selectAll(textNodeStatus)
@@ -1200,3 +1314,30 @@ export const moveClusterCountText = svg => {
       })
     })
 }
+
+export const moveArgoAppCountText = svg => {
+  svg
+    .select('g.nodes')
+    .selectAll(gArgoAppCountText)
+    .filter(({ layout: { x, y } }) => {
+      return x !== undefined && y !== undefined
+    })
+    .each(({ layout }, i, ns) => {
+      const { x, y } = layout
+      const argoAppCountText = d3.select(ns[i])
+
+      argoAppCountText.selectAll('text').attrs(() => {
+        return {
+          x: x + NODE_RADIUS - 2,
+          y: y + 4
+        }
+      })
+      argoAppCountText.selectAll('tspan.count').attrs(() => {
+        return {
+          x: x + NODE_RADIUS - 2,
+          y: y + 4,
+          dy: 0
+        }
+      })
+    })
+}
