@@ -12,7 +12,11 @@ import { UPDATE_ACTION_MODAL } from '../../apollo-client/queries/StateQueries'
 import { syncApplication } from '../../actions/application'
 import resources from '../../../lib/shared/resources'
 import { withLocale } from '../../providers/LocaleProvider'
-import { AcmModal, AcmLoadingPage, AcmAlert } from '@stolostron/ui-components'
+import {
+  AcmModal,
+  AcmLoadingPage,
+  AcmAlert
+} from '@open-cluster-management/ui-components'
 import { Button, ModalVariant } from '@patternfly/react-core'
 
 resources(() => {
@@ -138,7 +142,8 @@ class SyncResourceModal extends React.Component {
             selfLink: '',
             _uid: '',
             kind: '',
-            apiVersion: ''
+            apiVersion: '',
+            itemGroup: []
           }
         }
       })
