@@ -1,6 +1,5 @@
-/*******************************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import {
   getActiveChannel,
@@ -190,11 +189,21 @@ describe("hcm-application-diagram-tests", () => {
 
   it("getDiagramElements with pods container info", () => {
     const nodes = [
+      {
+        id: "member--clusters--",
+        type: "cluster"
+      },
       {
         id:
-          "member--clusters--possiblereptile, braveman, sharingpenguin, relievedox",
+          "member--clusters--possiblereptile,braveman,sharingpenguin,relievedox",
         type: "cluster",
         specs: {
+          clustersNames: [
+            "possiblereptile",
+            "braveman",
+            "sharingpenguin",
+            "relievedox"
+          ],
           clusters: [
             {
               metadata: {
@@ -225,7 +234,7 @@ describe("hcm-application-diagram-tests", () => {
       },
       {
         id:
-          "--clusters--possiblereptile, braveman, sharingpenguin, relievedox--app",
+          "application--clusters--possiblereptile,braveman,sharingpenguin,relievedox--app",
         type: "application",
         name: "aa",
         namespace: "ns",
@@ -233,12 +242,19 @@ describe("hcm-application-diagram-tests", () => {
           specs: {
             clusters: []
           }
+        },
+        specs: {
+          clustersNames: [
+            "possiblereptile",
+            "braveman",
+            "sharingpenguin",
+            "relievedox"
+          ]
         }
       },
       {
         type: "deployment",
-        id:
-          "--clusters--possiblereptile, braveman, sharingpenguin, relievedox--depl",
+        id: "--clusters--depl",
         name: "depl",
         cluster: null,
         clusterName: null,
@@ -246,9 +262,7 @@ describe("hcm-application-diagram-tests", () => {
           specs: {
             clusters: [
               {
-                metadata: {
-                  name: "possiblereptile"
-                },
+                name: "possiblereptile",
                 status: "ok"
               },
               {
@@ -291,7 +305,7 @@ describe("hcm-application-diagram-tests", () => {
       {
         type: "deployment",
         id:
-          "--clusters--possiblereptile, braveman, sharingpenguin, relievedox--depl",
+          "--clusters--possiblereptile,braveman,sharingpenguin,relievedox--depl",
         name: "depl2",
         clusters: {
           specs: {
@@ -306,6 +320,12 @@ describe("hcm-application-diagram-tests", () => {
           }
         },
         specs: {
+          clustersNames: [
+            "possiblereptile",
+            "braveman",
+            "sharingpenguin",
+            "relievedox"
+          ],
           raw: {
             spec: {
               template: {
@@ -324,7 +344,7 @@ describe("hcm-application-diagram-tests", () => {
       {
         type: "subscription",
         id:
-          "--clusters--possiblereptile, braveman, sharingpenguin, relievedox--subs",
+          "--clusters--possiblereptile,braveman,sharingpenguin,relievedox--subs",
         name: "subsname",
         clusters: {
           specs: {
@@ -332,6 +352,12 @@ describe("hcm-application-diagram-tests", () => {
           }
         },
         specs: {
+          clustersNames: [
+            "possiblereptile",
+            "braveman",
+            "sharingpenguin",
+            "relievedox"
+          ],
           raw: {
             spec: {
               template: {
@@ -369,6 +395,15 @@ describe("hcm-application-diagram-tests", () => {
           name: "mortgage-app",
           namespace: "default",
           related: [
+            {
+              kind: "cluster",
+              items: [
+                {
+                  name: "sharingpenguin",
+                  status: "ok"
+                }
+              ]
+            },
             {
               items: [
                 {
@@ -546,9 +581,31 @@ describe("hcm-application-diagram-tests", () => {
       status: "DONE"
     };
     const res = [
+      {
+        id: "member--clusters--",
+        specs: {
+          appClusters: [],
+          clusters: [
+            {
+              name: "sharingpenguin",
+              status: "ok"
+            }
+          ],
+          clustersNames: ["sharingpenguin"],
+          searchClusters: [
+            {
+              name: "sharingpenguin",
+              status: "ok"
+            }
+          ],
+          pulse: "green",
+          shapeType: "cluster"
+        },
+        type: "cluster"
+      },
       {
         id:
-          "member--clusters--possiblereptile, braveman, sharingpenguin, relievedox",
+          "member--clusters--possiblereptile,braveman,sharingpenguin,relievedox",
         specs: {
           clusters: [
             {
@@ -576,6 +633,12 @@ describe("hcm-application-diagram-tests", () => {
               status: "ok"
             }
           ],
+          clustersNames: [
+            "braveman",
+            "possiblereptile",
+            "relievedox",
+            "sharingpenguin"
+          ],
           pulse: "green",
           shapeType: "cluster"
         },
@@ -588,10 +651,17 @@ describe("hcm-application-diagram-tests", () => {
           }
         },
         id:
-          "--clusters--possiblereptile, braveman, sharingpenguin, relievedox--app",
+          "application--clusters--possiblereptile,braveman,sharingpenguin,relievedox--app",
         name: "aa",
         namespace: "ns",
         specs: {
+          allClusters: { isLocal: false, remoteCount: 1 },
+          clustersNames: [
+            "braveman",
+            "possiblereptile",
+            "relievedox",
+            "sharingpenguin"
+          ],
           pulse: "red",
           shapeType: "application"
         },
@@ -600,45 +670,10 @@ describe("hcm-application-diagram-tests", () => {
       {
         cluster: null,
         clusterName: null,
-        clusters: {
-          id:
-            "member--clusters--possiblereptile, braveman, sharingpenguin, relievedox",
-          specs: {
-            clusters: [
-              {
-                metadata: {
-                  name: "possiblereptile"
-                },
-                status: "ok"
-              },
-              {
-                metadata: {
-                  name: "braveman"
-                },
-                status: "ok"
-              },
-              {
-                metadata: {
-                  name: "sharingpenguin"
-                },
-                status: "ok"
-              },
-              {
-                metadata: {
-                  name: "relievedox"
-                },
-                status: "ok"
-              }
-            ],
-            pulse: "green",
-            shapeType: "cluster"
-          },
-          type: "cluster"
-        },
-        id:
-          "--clusters--possiblereptile, braveman, sharingpenguin, relievedox--depl",
+        id: "--clusters--depl",
         name: "depl",
         specs: {
+          clustersNames: ["depl", "sharingpenguin"],
           pulse: "orange",
           raw: {
             spec: {
@@ -661,7 +696,7 @@ describe("hcm-application-diagram-tests", () => {
       {
         clusters: {
           id:
-            "member--clusters--possiblereptile, braveman, sharingpenguin, relievedox",
+            "member--clusters--possiblereptile,braveman,sharingpenguin,relievedox",
           specs: {
             clusters: [
               {
@@ -689,15 +724,27 @@ describe("hcm-application-diagram-tests", () => {
                 status: "ok"
               }
             ],
+            clustersNames: [
+              "braveman",
+              "possiblereptile",
+              "relievedox",
+              "sharingpenguin"
+            ],
             pulse: "green",
             shapeType: "cluster"
           },
           type: "cluster"
         },
         id:
-          "--clusters--possiblereptile, braveman, sharingpenguin, relievedox--depl",
+          "--clusters--possiblereptile,braveman,sharingpenguin,relievedox--depl",
         name: "depl2",
         specs: {
+          clustersNames: [
+            "braveman",
+            "possiblereptile",
+            "relievedox",
+            "sharingpenguin"
+          ],
           pulse: "orange",
           raw: {
             spec: {
@@ -720,7 +767,7 @@ describe("hcm-application-diagram-tests", () => {
       {
         clusters: {
           id:
-            "member--clusters--possiblereptile, braveman, sharingpenguin, relievedox",
+            "member--clusters--possiblereptile,braveman,sharingpenguin,relievedox",
           specs: {
             clusters: [
               {
@@ -748,15 +795,27 @@ describe("hcm-application-diagram-tests", () => {
                 status: "ok"
               }
             ],
+            clustersNames: [
+              "braveman",
+              "possiblereptile",
+              "relievedox",
+              "sharingpenguin"
+            ],
             pulse: "green",
             shapeType: "cluster"
           },
           type: "cluster"
         },
         id:
-          "--clusters--possiblereptile, braveman, sharingpenguin, relievedox--subs",
+          "--clusters--possiblereptile,braveman,sharingpenguin,relievedox--subs",
         name: "subsname",
         specs: {
+          clustersNames: [
+            "braveman",
+            "possiblereptile",
+            "relievedox",
+            "sharingpenguin"
+          ],
           pulse: "orange",
           raw: {
             spec: {
