@@ -1,6 +1,5 @@
-/*******************************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 "use strict";
 
 import {
@@ -32,8 +31,6 @@ const applicationNodes = [
       nodeStatus: "",
       search: "",
       title: "",
-      type: "application",
-      uid: "application--nginx-app-3",
       x: 1.5,
       y: 1.5
     },
@@ -51,6 +48,49 @@ const applicationNodes = [
   }
 ];
 
+const argoApplicationNodes = [
+  {
+    cluster: null,
+    clusterName: null,
+    id: "application--nginx-app-3",
+    labels: null,
+    layout: {
+      uid: "application--nginx-app-3",
+      type: "application",
+      label: "nginx-app-3",
+      compactLabel: "nginx-app-3",
+      nodeIcons: {
+        classType: "failure",
+        dx: 16,
+        dy: -16,
+        height: 16,
+        icon: "failure",
+        width: 16
+      },
+      nodeStatus: "",
+      search: "",
+      title: "",
+      x: 1.5,
+      y: 1.5
+    },
+    name: "nginx-app-3",
+    namespace: "ns-sub-1",
+    specs: {
+      isDesign: true,
+      row: 0,
+      pulse: "orange",
+      raw: {
+        apiVersion: "argoproj.io/v1alpha1"
+      },
+      relatedApps: []
+    },
+    topology: null,
+    type: "application",
+    uid: "application--nginx-app-3",
+    __typename: "Resource"
+  }
+];
+
 const clusterNodes = [
   {
     id: "member--clusters--cluster1",
@@ -662,3 +702,9 @@ describe("updateNodeIcons application nodes red", () => {
     expect(updateNodeIcons(applicationNodesRed, locale)).toEqual(undefined);
   });
 });
+
+describe("updateNodeIcons test Argo application", () => {
+  it("should update the Argo application node", () => {
+    expect(updateNodeIcons(argoApplicationNodes, locale)).toEqual(undefined);
+  });
+});
